# ASN.1 module IMZM-PDU-Descriptions
 OID: _{ itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (103724) imzm (1) version (1) }_
 Specification of the Interference Management Zone Message ETSI TS 103 724<br/>

 Latest version available at https://forge.etsi.org/rep/ITS/asn1/imzm_ts103724

## Imports:
 * **ITS-Container** *{ itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (102894) cdd (2) version (2) }*<br/>
    Include ETSI TS 102 894-2 references from https://forge.etsi.org/rep/ITS/asn1/cdd_ts102894_2/blob/master/ITS-Container.asn

 * **CAM-PDU-Descriptions** *{ itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) en (302637) cam (2) version (2) }*<br/>
    Include ETSI EN 302 637-2 references from https://forge.etsi.org/rep/ITS/asn1/cam_en302637_2/blob/master/CAM-PDU-Descriptions.asn

 * **VAM-Temp-Imports** *{ itu-t(0) identified-organization(4) etsi(0) itsDomain(5) wg1(1) ts(103300) temp-imports(255) version1(1) }*<br/>
    Include ETSI TS 103 300-3 references from https://forge.etsi.org/rep/ITS/asn1/vam-ts103300_3/blob/master/VAM-Temp-Imports.asn <br>
   This is temporary * :<br>
   Import from **VAM-Temp-Imports** will be changed to CDD ETSI TS 102 894-2 Release 2 when available*

## Data Elements:
### <a name="IMZM"></a>IMZM

 This DF includes DEs for the IMZM `protocolVersion`, the IMZ message type identifier `messageID`
 and the station identifier `stationID` of the originating ITS-S.


Fields:
* header [**ItsPduHeader**](ITS-Container.md#ItsPduHeader) <br>
    The DE `protocolVersion` is used to select the appropriate protocol decoder at the receiving ITS-S.
      For TS 103 724 V2.1.1, the value of the DE `protocolVersion` shall be set to `1`.
    The DE `messageID` shall be harmonized with other V2X message identifier definitions.
      For IMZM, the DE `messageID` shall be set to `imzm(15)`.
* imzm [**InterferenceManagementZoneMessage**](#InterferenceManagementZoneMessage) <br>
```asn1
IMZM ::= SEQUENCE {
   header ItsPduHeader,
   imzm InterferenceManagementZoneMessage
}
```

### <a name="InterferenceManagementZoneMessage"></a>InterferenceManagementZoneMessage

 This DF is the actual [**IMZM**](#IMZM) Payload. It shall include the time stamp of the [**IMZM**](#IMZM) and the applicable
 containers of type [**BasicContainer**](CAM-PDU-Descriptions.md#BasicContainer) and [**ImzmContainer**](#ImzmContainer).


Fields:
* generationDeltaTime [**GenerationDeltaTime**](CAM-PDU-Descriptions.md#GenerationDeltaTime) <br>
* imzmParameters [**ImzmParameters**](#ImzmParameters) <br>
```asn1
InterferenceManagementZoneMessage ::= SEQUENCE {
   generationDeltaTime GenerationDeltaTime, -- from CAM-PDU-Descriptions
   imzmParameters ImzmParameters
}
```

### <a name="ImzmParameters"></a>ImzmParameters

 This DF defines the  sequence of containers in the [**IMZM**](#IMZM). Other containers may be added in the future.


Fields:
* basicContainer [**BasicContainer**](CAM-PDU-Descriptions.md#BasicContainer) <br>
    imported from [**CAM-PDU-Descriptions**](#CAM-PDU-Descriptions)
* imzmContainer [**ImzmContainer**](#ImzmContainer) <br>
    container specific to the [**IMZM**](#IMZM)
```asn1
ImzmParameters ::= SEQUENCE {
    basicContainer BasicContainer, 
    imzmContainer ImzmContainer,
   ...
}
```

### <a name="ImzmContainer"></a>ImzmContainer

 The DF for IMZM container includes a sequence of up to 16 interference management zones.
 For each interference management zones, it contains a sequence of interference
 management zones per channel together with their characteristics.


Fields:
* interferenceManagementZones [**InterferenceManagementZones**](#InterferenceManagementZones) <br>
    Mapped to the DF [**ProtectedCommunicationZone**](#ProtectedCommunicationZone) in ETSI TS 102 894-2
```asn1
ImzmContainer ::= SEQUENCE {
    interferenceManagementZones InterferenceManagementZones,
    ...
}
```

### <a name="InterferenceManagementZones"></a>InterferenceManagementZones

 This DF is made of a list of up to 16 interference management zones.
 > EXAMPLE: An interference management communication zone may be defined around a
 >          CEN DSRC road side equipment or an urban rail operational area.
 
&nbsp;&nbsp;&nbsp;&nbsp;Categories: [Infrastructure information](#Infrastructure+information) [Communication information](#Communication+information) 




```asn1
InterferenceManagementZones ::= SEQUENCE (SIZE(1..16), ...) OF InterferenceManagementZone
```

### <a name="InterferenceManagementZone"></a>InterferenceManagementZone

 This DF describes a zone of interferenceManagement inside which the ITS communication should
 be restricted.
 
&nbsp;&nbsp;&nbsp;&nbsp;Categories: [Infrastructure information](#Infrastructure+information) [Communication information](#Communication+information) 




Fields:
* zoneDefinition [**ZoneDefinition**](#ZoneDefinition) <br>
* interferenceManagementInfo [**InterferenceManagementInfo**](#InterferenceManagementInfo) <br>
```asn1
InterferenceManagementZone ::= SEQUENCE {
	zoneDefinition             ZoneDefinition,
	interferenceManagementInfo InterferenceManagementInfo
}
```

### <a name="ZoneDefinition"></a>ZoneDefinition

 This DF describes the zone where band sharing occurs. When reusing CDD Rel.1 types, names are unchanged.
 
&nbsp;&nbsp;&nbsp;&nbsp;Categories: [Infrastructure information](#Infrastructure+information) [Communication information](#Communication+information) 




Fields:
* interferenceManagementZoneLatitude [**Latitude**](ITS-Container.md#Latitude) <br>
    Latitude of the centre point of the interference management zone.
* interferenceManagementZoneLongitude [**Longitude**](ITS-Container.md#Longitude) <br>
    from ITS-Container
    Longitude of the centre point of the interference management zone.
* interferenceManagementZoneRadius [**ProtectedZoneRadius**](ITS-Container.md#ProtectedZoneRadius)  OPTIONAL<br>
    from ITS-Container
    Radius of the interference management zone in metres.
* interferenceManagementZoneID [**ProtectedZoneID**](ITS-Container.md#ProtectedZoneID)  OPTIONAL<br>
    from ITS-Container
    Identification of the interference management zone.
* interferenceManagementZoneShape [**InterferenceManagementZoneShape**](#InterferenceManagementZoneShape)  OPTIONAL<br>
    from ITS-Container
    Shape of the interference management zone.
```asn1
ZoneDefinition::= SEQUENCE{     
    interferenceManagementZoneLatitude   Latitude, --! from ITS-Container
    interferenceManagementZoneLongitude  Longitude, --! from ITS-Container
    interferenceManagementZoneRadius     ProtectedZoneRadius OPTIONAL, --! from ITS-Container
    interferenceManagementZoneID         ProtectedZoneID OPTIONAL, --! from ITS-Container
    interferenceManagementZoneShape      InterferenceManagementZoneShape OPTIONAL,
    ...
}
```

### <a name="InterferenceManagementInfo"></a>InterferenceManagementInfo

 This DF includes a list of up to 16 definitions containing which interference management may be applied in the zone,
 per affected frequency channels.
 NOTE: in the case where no mitigation should be applied by the ITS-S, this is indicated
 by the value of interferenceManagementMitigationType set to unavailable.
 
&nbsp;&nbsp;&nbsp;&nbsp;Categories: [Infrastructure information](#Infrastructure+information) [Communication information](#Communication+information) 




```asn1
InterferenceManagementInfo::= SEQUENCE (SIZE(1..16,...)) OF InterferenceManagementInfoPerChannel
```

### <a name="InterferenceManagementInfoPerChannel"></a>InterferenceManagementInfoPerChannel

 This DF is a break up of the interference management information per affected frequency channels.
 
&nbsp;&nbsp;&nbsp;&nbsp;Categories: [Infrastructure information](#Infrastructure+information) [Communication information](#Communication+information) 




Fields:
* interferenceManagementChannel [**InterferenceManagementChannel**](#InterferenceManagementChannel) <br>
    Characteritics of the frequency channel for which the zone should be applied interference management
* interferenceManagementZoneType [**InterferenceManagementZoneType**](#InterferenceManagementZoneType) <br>
    Type of the interference management zone.
* interferenceManagementMitigationType [**InterferenceManagementMitigationType**](#InterferenceManagementMitigationType)  OPTIONAL<br>
    Type of the mitigation to be used in the interference management zone.
* expiryTime [**TimestampIts**](ITS-Container.md#TimestampIts)  OPTIONAL<br>
    Time at which the validity of the interference management communication zone will expire.
    > The `expiryTime` DE is present when the interference management is temporarily valid.
```asn1
InterferenceManagementInfoPerChannel ::= SEQUENCE {
    interferenceManagementChannel         InterferenceManagementChannel,
    interferenceManagementZoneType        InterferenceManagementZoneType,
    interferenceManagementMitigationType  InterferenceManagementMitigationType OPTIONAL,
    expiryTime                            TimestampIts OPTIONAL, --! from ITS-Container
    ...
}
```

### <a name="InterferenceManagementChannel"></a>InterferenceManagementChannel

 This DF indicates which shared frequency channel should be applied interference management in the zone.
 
&nbsp;&nbsp;&nbsp;&nbsp;Categories: [Communication information](#Communication+information) 




Fields:
* centreFrequency **INTEGER**  (1 .. 99999)<br>
    Centre of the channel frequency<br>
    Units:  10exp+2 Hz (where exp is exponent)
* channelWidth **INTEGER**  (0 .. 9999)<br>
    Width of the channel<br>
    Units: 10exp Hz (where exp is exponent)
* exponent **INTEGER**  (0 .. 15) <br>
    Exponent of the power of 10<br>
    Units: N/A
```asn1
InterferenceManagementChannel ::= SEQUENCE {
    centreFrequency INTEGER (1 .. 99999),
    channelWidth    INTEGER (0 .. 9999),
    exponent        INTEGER (0 .. 15) 
}
```

### <a name="InterferenceManagementZoneType"></a>InterferenceManagementZoneType

 This DE defines the type of an interference management zone, so that an ITS-S can
 assert the actions to do while passing by such zone (e.g. reduce the transmit
 power in case of a DSRC tolling station).<br>
 Units: N/A
 
&nbsp;&nbsp;&nbsp;&nbsp;Categories: [Communication information](#Communication+information) 




Fields:
```asn1
InterferenceManagementZoneType ::= ENUMERATED {
    permanentCenDsrcTolling(0), --! as specified in ETSI TS 102 792
    temporaryCenDsrcTolling(1), --! as specified in ETSI TS 102 792
    unavailable(2),  --! default value. Set to 2 for backwards compatibility with DSRC tolling
    urbanRail(3),    --! as specified in ETSI TS 103 724, clause 7
    satelliteStation(4),  --! as specified in ETSI TS 103 724, clause 7
    fixedLinks(5),   --! as specified in ETSI TS 103 724, clause 7
    ...
}
```

### <a name="InterferenceManagementMitigationType"></a>InterferenceManagementMitigationType

 This DF defines the mitigation type in the interference management zone.
 Information and commands defining the required mitigation type the
 receiving ITS-S has to use in the defined interference management zone.
 It indicates the type of mitigation and the parameters to be used to protect the
 potential victim in the interference management zone per channel access technology class.
 
&nbsp;&nbsp;&nbsp;&nbsp;Categories: [Communication information](#Communication+information) 




Fields:
* unavailable [**NULL**](#NULL) <br>
    unavailable is the default value to be used when data is not available
* mitigationForTechnologies [**MitigationForTechnologies**](#MitigationForTechnologies) <br>
```asn1
InterferenceManagementMitigationType ::= CHOICE {
    unavailable   NULL,   
    mitigationForTechnologies MitigationForTechnologies
}
```

### <a name="MitigationForTechnologies"></a>MitigationForTechnologies

 This DF defines the mitigation type container for the different channel access technology classes.<br>
 Class of parameters for the relevant channel access technology classes,
 as specified in ETSI TS 103 724, clause 7.
 
&nbsp;&nbsp;&nbsp;&nbsp;Categories: [Communication information](#Communication+information) 




```asn1
MitigationForTechnologies ::= SEQUENCE (SIZE(1..8)) OF MitigationPerTechnologyClass
```

### <a name="MitigationPerTechnologyClass"></a>MitigationPerTechnologyClass

 This DF defines the mitigation type container per channel access technology class <br>
 Class of parameters for the specific technology indicated in the container.
 All parameters are optional, as they may not apply to some of the technologies or
 interference management zone types. Specification details are in ETSI TS 103 724, clause 7.
 
&nbsp;&nbsp;&nbsp;&nbsp;Categories: [Communication information](#Communication+information) 




Fields:
* accessTechnologyClass [**AccessTechnologyClass**](#AccessTechnologyClass) <br>
    Channel access technology in which this mitigation is applied.
    Units: N/A
* lowDutyCycle **INTEGER**  (0 .. 10000) OPTIONAL<br>
    Duty cycle limit<br>
    Units: 0.01% of steps
* powerReduction **INTEGER**  (0 .. 30) OPTIONAL<br>
    Power reduction<br>
    Units: dB
* dmcToffLimit **INTEGER**  (0 .. 1200) OPTIONAL<br>
    Idle time limit, as defined in ETSI TS 103 175.<br>
    Units: ms
* dmcTonLimit **INTEGER**  (0 .. 20) OPTIONAL<br>
    Transmission duration limit, as defined in ETSI EN 302 571.<br>
    Units: ms
```asn1
MitigationPerTechnologyClass ::= SEQUENCE {
     accessTechnologyClass  AccessTechnologyClass, 
   lowDutyCycle  INTEGER (0 .. 10000) OPTIONAL, 
   powerReduction INTEGER (0 .. 30) OPTIONAL,
   dmcToffLimit   INTEGER (0 .. 1200) OPTIONAL,   
   dmcTonLimit   INTEGER (0 .. 20) OPTIONAL,   
   ...
}
```

### <a name="AccessTechnologyClass"></a>AccessTechnologyClass

 This DE indicates the access technology to which the mitigation type applies.
 
&nbsp;&nbsp;&nbsp;&nbsp;Categories: [Communication information](#Communication+information) 




Fields:
```asn1
AccessTechnologyClass ::= ENUMERATED {
   any(0),
   itsg5Class(1), 
   ltev2xClass(2),
   nrv2xClass(3), 
   ...
}
```

### <a name="InterferenceManagementZoneShape"></a>InterferenceManagementZoneShape

 This DF defines the shape of the interference management zone.
 It represents the bounding box of an interference management zone
 
&nbsp;&nbsp;&nbsp;&nbsp;Categories: [GeoReference information](#GeoReference+information) 




Fields:
* rectangle [**AreaRectangle**](VAM-Temp-Imports.md#AreaRectangle) <br>
* circle [**AreaCircular**](VAM-Temp-Imports.md#AreaCircular) <br>
    imported from VAM-Temp-Imports
* polygon [**AreaPolygon**](VAM-Temp-Imports.md#AreaPolygon) <br>
    imported from VAM-Temp-Imports
* ellipse [**AreaEllipse**](#AreaEllipse) <br>
    imported from VAM-Temp-Imports
```asn1
InterferenceManagementZoneShape::= CHOICE {
   rectangle    AreaRectangle, --! imported from VAM-Temp-Imports
   circle       AreaCircular, --! imported from VAM-Temp-Imports
   polygon      AreaPolygon, --! imported from VAM-Temp-Imports
   ellipse      AreaEllipse, --! could not be imported from another specification yet
   ...
}
```



